package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.TmstruckEnfactoryResultMapper;
import com.steerinfo.dil.model.TmstruckEnfactoryResult;
import com.steerinfo.dil.service.ITmstruckEnfactoryResultService;
import com.steerinfo.dil.util.DataChange;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * TmstruckEnfactoryResult服务实现：
 * @author TXF
 * @version 1.0-SNAPSHORT 2021-09-08 06:23
 * 类描述
 * 修订历史：
 * 日期：2021-09-08
 * 作者：generator
 * 参考：
 * 描述：TmstruckEnfactoryResult服务实现
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@Service(value = "tmstruckEnfactoryResultService")
public class TmstruckEnfactoryResultServiceImpl implements ITmstruckEnfactoryResultService {

    @Autowired
    private TmstruckEnfactoryResultMapper tmstruckEnfactoryResultMapper;

    @Autowired
    private TmstruckMeasureCommissionServiceImpl tmstruckMeasureCommissionService;

    @Autowired
    private UtilsServiceImpl utilsService;



    /**
     * 派单时新增进厂实绩
     * map: 总实绩Id、线路起点
     * @param map
     * @return
     */
    @Override
    public int addEnFactoryResult(Map<String, Object> map) {
        TmstruckEnfactoryResult tmstruckEnfactoryResult = new TmstruckEnfactoryResult();
        //生成进厂作业主键Id
        //添加主键
        tmstruckEnfactoryResult.setResultId(tmstruckEnfactoryResultMapper.selectMaxId());
        //添加门岗ID 路线起点就是进厂门岗
        tmstruckEnfactoryResult.setGatepostId(DataChange.dataToBigDecimal(map.get("lineStartNodeId")));
        //添加实绩总表Id
        tmstruckEnfactoryResult.setResultTotalId(DataChange.dataToBigDecimal(map.get("resultTotalId")));
        return tmstruckEnfactoryResultMapper.insertSelective(tmstruckEnfactoryResult);
    }

    /**
     * 通过运输订单号查找排队顺序号
     * @param orderNumber
     * @return
     */
    @Override
    public Integer selectNodeNumber(String orderNumber) {
        return tmstruckEnfactoryResultMapper.selectNodeNumber(orderNumber);
    }

    /**
     * 获取进厂实绩
     * 1：销售订单；2：焦炭发运计划；3：水渣发运计划；4：内转到异地库；5：采购辅料订单；6：采购老区燃料订单；
     * 7：采购新区燃料订单；8：采购进口矿(万州-厂内)；9：采购内转(达州-厂内)；10：采购内转(老区-厂内)； 11：厂内内转
     * @param map
     * @return
     */
    @Override
    public List<Map<String, Object>> getAllEnFactoryResult(Map<String, Object> map) {
        Integer orderType = (Integer) map.get("orderTypee");
        switch (orderType){
            case 1:
                return tmstruckEnfactoryResultMapper.getCGJKEnFactoryResult(map);
            case 2:

                break;
            case 3:

                break;
            case 4:

                break;
            case 5:
            case 6:
            case 7:
            case 8:
                return tmstruckEnfactoryResultMapper.getCGJKEnFactoryResult(map);
            case 9:

                break;
            case 10:

                break;
            case 11:


        }
        return null;
    }



    /**
     * 通过PDA进厂
     * orderNumber 运输订单号 gatepostName 门岗名称
     * 1：销售订单；2：焦炭发运计划；3：水渣发运计划；4：内转到异地库；5：采购辅料订单；6：采购老区燃料订单；
     * 7：采购新区燃料订单；8：采购进口矿(万州-厂内)；9：采购内转(达州-厂内)；10：采购内转(老区-厂内)； 11：厂内内转
     * @param map
     * @return
     */
    public int enFactoryResultByPDA(Map<String, Object> map){
        int i = 0;
        //通过运输订单号查询订单类型
        String orderNumber = (String) map.get("orderNumber");
        map.putAll(tmstruckEnfactoryResultMapper.selectEnFactoryResultId(orderNumber));
        BigDecimal orderType = DataChange.dataToBigDecimal(map.get("orderTypee"));
        switch (orderType.intValue()){
            case 1:
            case 4:
            case 11:
                i += updateEnFactoryResultByPDA(map); //添加进厂实绩
                i += tmstruckMeasureCommissionService.addPiMeasureCommission(map); //添加计皮委托
                i += utilsService.updateOrderLineSequence(map, 4);//修改路段顺序号 4：计皮
                break;
            case 2:
                break;
            case 5:
            case 6:
            case 7:
            case 8:
            case 9:
                i += updateEnFactoryResultByPDA(map); //添加进厂实绩
                i += tmstruckMeasureCommissionService.addMaoMeasureCommission(map); //添加计毛委托 并发送计毛委托
                i += utilsService.updateOrderLineSequence(map, 2);//修改路段顺序号 2：计毛
                break;
            case 10: // 采购内转（老区-厂内）
                break;
        }
        return i;
    }

    /**
     * 通过门禁进厂
     * 运输订单号 orderNumber，车牌号capacityNumber，
     * 门岗名称 gatepostName，进厂时间 resultEntryGateTime，（进厂方式）
     * @param map
     * @return
     */
    public int enFactoryResultByMJ(Map<String, Object> map){
        int i = 0;
        //通过运输订单号查询订单类型
        String orderNumber = (String) map.get("orderNumber");
        map.putAll(tmstruckEnfactoryResultMapper.selectEnFactoryResultId(orderNumber));
        BigDecimal orderType = DataChange.dataToBigDecimal(map.get("orderTypee"));
        switch (orderType.intValue()){
            case 1:
            case 4:
            case 11:
                i += updateEnFactoryResultByMJ(map); //添加进厂实绩
                i += tmstruckMeasureCommissionService.addPiMeasureCommission(map); //添加计皮委托
                i += utilsService.updateOrderLineSequence(map, 4);//修改路段顺序号 4：计皮
                break;
            case 2:
                break;
            case 5:
            case 6:
            case 7:
            case 8:
            case 9:
                i += updateEnFactoryResultByMJ(map); //添加进厂实绩
                i += tmstruckMeasureCommissionService.addMaoMeasureCommission(map); //添加计毛委托 并发送计毛委托
                i += utilsService.updateOrderLineSequence(map, 2);//修改路段顺序号 2：计毛
                break;
            case 10: // 采购内转（老区-厂内）
                break;
        }
        return i;
    }

    /**
     * 通过PDA添加进厂实绩方法
     * @param map
     * @return
     */
    public int updateEnFactoryResultByPDA(Map<String, Object> map){
        TmstruckEnfactoryResult tmstruckEnfactoryResult = new TmstruckEnfactoryResult();
        //获取进厂实绩id
        tmstruckEnfactoryResult.setResultId(DataChange.dataToBigDecimal(map.get("resultId")));
        //添加门岗
        String gatepostName = (String) map.get("gatepostName");
        Integer gatepostId = tmstruckEnfactoryResultMapper.selectGatepostIdByGatepostName(gatepostName);
        tmstruckEnfactoryResult.setGatepostId(new BigDecimal(gatepostId));
        //添加进厂时间
        tmstruckEnfactoryResult.setResultEntryGateTime(new Date());
        tmstruckEnfactoryResult.setInsertTime(new Date());
        tmstruckEnfactoryResult.setResultEntryMode("手动抬杠");
        tmstruckEnfactoryResult.setInsertUsername("admin");
        return tmstruckEnfactoryResultMapper.updateByPrimaryKeySelective(tmstruckEnfactoryResult);
    }

    /**
     * 通过门禁系统添加进厂实绩方法
     * @param map
     * @return
     */
    public int updateEnFactoryResultByMJ(Map<String, Object> map){
        TmstruckEnfactoryResult tmstruckEnfactoryResult=new TmstruckEnfactoryResult();
        //进门方式
        tmstruckEnfactoryResult.setResultEntryMode("自动抬杆");
        //添加进厂时间
        tmstruckEnfactoryResult.setResultEntryGateTime(new Date((long) map.get("resultEntryGateTime")));
        //添加门岗
        String gatepostName = (String) map.get("gatepostName");
        Integer gatepostNameId = tmstruckEnfactoryResultMapper.selectGatepostIdByGatepostName(gatepostName);
        tmstruckEnfactoryResult.setGatepostId(new BigDecimal(gatepostNameId));

        tmstruckEnfactoryResult.setInsertTime(new Date());
        tmstruckEnfactoryResult.setInsertUsername("admin");
        return tmstruckEnfactoryResultMapper.updateByPrimaryKeySelective(tmstruckEnfactoryResult);
    }
}
