package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.feign.OmsFeign;
import com.steerinfo.dil.mapper.TmstruckReturnResultMapper;
import com.steerinfo.dil.mapper.TmstruckTotalResultMapper;
import com.steerinfo.dil.model.TmstruckReturnResult;
import com.steerinfo.dil.model.TmstruckTotalResult;

import com.steerinfo.dil.service.ITmstruckReturnResultService;
import com.steerinfo.dil.util.DataChange;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * TmstruckReturnResult服务实现：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-10-18 09:17
 * 类描述
 * 修订历史：
 * 日期：2021-10-18
 * 作者：generator
 * 参考：
 * 描述：TmstruckReturnResult服务实现
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@Service(value = "tmstruckReturnResultService")
public class TmstruckReturnResultServiceImpl implements ITmstruckReturnResultService {

    @Autowired
    private TmstruckReturnResultMapper tmstruckReturnResultMapper;

    @Autowired
    private UtilsServiceImpl utilsService;

    @Autowired
    private OmsFeign omsFeign;

    @Autowired
    private TmstruckTotalResultMapper tmstruckTotalResultMapper;

    @Autowired
    private TmstruckEnfactoryResultServiceImpl tmstruckEnfactoryResultService;
    @Autowired
    private TmstruckLeaveFactoryResultServiceImpl tmstruckLeaveFactoryResultService;
    @Autowired
    private TmstruckWeightResultServiceImpl tmstruckWeightResultService;

    /**
     * 添加常规字段
     * @param tmstruckReturnResult
     */
    public void addRegularField(TmstruckReturnResult tmstruckReturnResult){
        tmstruckReturnResult.setInsertTime(new Date());
        tmstruckReturnResult.setInsertUsername("admin");
    }

    /**
     * 添加退货实绩 删除本条运输订单 重新新增销售运输订单 、运输订单子表  以及进厂、出厂等实绩
     * @param map {orderNumber 运输订单号}
     * @return
     */
    @Override
    public int addReturnGoodsResult(Map<String, Object> map) {
        TmstruckReturnResult tmstruckReturnResult = new TmstruckReturnResult();
        //生成主键
        BigDecimal maxId = tmstruckReturnResultMapper.selectMaxId();
        tmstruckReturnResult.setResultId(maxId);
        //通过运输订单号获得 运输订单ID
        map.putAll(tmstruckReturnResultMapper.getResultTotalIdByOrderNumber((String) map.get("orderNumber")));
        tmstruckReturnResult.setResultTotalId(DataChange.dataToBigDecimal(map.get("resultTotalId")));
        BigDecimal orderId = DataChange.dataToBigDecimal(map.get("orderId"));
        //设置首次新增时的常规字段
        addRegularField(tmstruckReturnResult);
        //新增退货实绩
        int i = tmstruckReturnResultMapper.insertSelective(tmstruckReturnResult);
        //逻辑删除运单
        int i1 = utilsService.updateOrderStatus(map, 7);
        //重新新增销售运输订单
        int i2 = addNewOrder(orderId);
        return i + i1 + i2;
    }


    /**
     * 重新新增销售运输订单
     * @param orderId
     * @return
     */
    public int addNewOrder(BigDecimal orderId){
        //通过运输订单ID查询上一个运输订单的相关信息
        Map<String, Object> omstruckOrder = tmstruckReturnResultMapper.getOldOrderMesById(orderId);
        //生成主键
        BigDecimal maxId = utilsService.selectOrderMaxId();
        omstruckOrder.put("orderId", maxId);
        //生成运输订单号
        omstruckOrder.put("orderNumber", DataChange.generateEightDigitsNumber("WYSDD", maxId.intValue()));
        //添加订单状态 1:执行中
        omstruckOrder.put("orderStatus", new BigDecimal(4));
        //添加常规字段
        omstruckOrder.put("insertTime",new Date());
        omstruckOrder.put("insertUsername","admin");
        //新增新的运输订单
        omsFeign.insertSelectiveOrder(omstruckOrder);
        //新增新的运输订单子表
        int i1 = addNewOrderMaterial(orderId, maxId);
        //新增总实绩 maxId为新订单ID
        int i2 = addTotalResult(maxId);
        //新增进厂、计重、出厂实绩
        int i3 = addAllResult(maxId);
        return i1 + i2 + i3;
    }

    /**
     * 总实绩新增一条数据
     * @param orderId
     * @return
     */
    public int addTotalResult(BigDecimal orderId){
        TmstruckTotalResult tmstruckTotalResult = new TmstruckTotalResult();
        //生成主键
        tmstruckTotalResult.setResultTotalId(tmstruckTotalResultMapper.selectMaxId());
        tmstruckTotalResult.setOrderId(orderId);
        return tmstruckTotalResultMapper.insertSelective(tmstruckTotalResult);
    }

    /**
     * 退货自动新增一条 进厂、计重、出厂实绩  遗留问题（装车）
     * @param orderId
     * @return
     */
    @Transactional
    public int addAllResult(BigDecimal orderId){
        //通过运输订单号 查询各个作业点ID 及 总实绩ID
        Map<String, Object> idMap = new HashMap<>();
        idMap.put("orderId", orderId);
        Map<String, Object> map = tmstruckReturnResultMapper.getPointIdByOrderNum(idMap);
        int i = tmstruckEnfactoryResultService.addEnFactoryResult(map);
        int i1 = tmstruckWeightResultService.addWeightResult(map);
        int i2 = tmstruckLeaveFactoryResultService.addLeaveFactory(map);
        return i + i1 + i2;
    }

    /**
     * 重新新增销售运输订单子表
     * @param oldOrderId 旧订单Id
     * @param newOrderId 新订单ID
     */
    public int addNewOrderMaterial(BigDecimal oldOrderId, BigDecimal newOrderId){
        //通过运输订单查询上一个运输订单子表相关的信息 可能会有多个物资信息
        List<Map<String, Object>> oldOrderMaterialList = tmstruckReturnResultMapper.getOldOrderMaterialMesByOrderId(oldOrderId);
        int count = 0;
        for (Map<String, Object> omstruckOrderMaterial : oldOrderMaterialList) {
            //获取主键
            omstruckOrderMaterial.put("orderMaterialId", utilsService.selectOrderMaterialMaxId());
            //设置新订单Id
            omstruckOrderMaterial.put("orderId", newOrderId);
            //添加常规字段
            omstruckOrderMaterial.put("insertTime",new Date());
            omstruckOrderMaterial.put("insertUsername","admin");
            omsFeign.insertSelectiveOrderMaterial(omstruckOrderMaterial);
            count++;
        }
        return count;
    }
}
